@@ -3,6 +3,7 @@ import difflib
 import re
 import requests
 from urllib.request import urlopen
+from collections import defaultdict
 
 
 class RTScraper:
@@ -47,6 +48,8 @@ class MovieScraper(RTScraper):
             movie_titles.append(movie['name'])
 
         closest = self.closest(self.movie_title, movie_titles)
+
+        url_movie = None
         for movie in search_result['movies']:
             if movie['name'] == closest[0]:
                 url_movie = 'https://www.rottentomatoes.com' + movie['url']
@@ -147,3 +150,55 @@ class CelebrityScraper(RTScraper):
                 except IOError:
                     pass
         self.metadata['movie_titles'] = movie_titles
+    
+    
+class DirectorScraper(RTScraper):
+    def __init__(self, **kwargs):
+        RTScraper.__init__(self)
+        if 'director_name' in kwargs.keys():
+            self.director_name = kwargs['director_name']
+            self.extract_url()
+        if 'director_url' in kwargs.keys():
+            self.url = kwargs['director_url']
+        if 'print' in kwargs.keys():
+            self.print = kwargs['print']
+
+    def extract_url(self):
+        search_result = self.search(term=self.director_name)
+        url_director = 'https://www.rottentomatoes.com' + search_result['actors'][0]['url']
+        self.url = url_director
+    
+    def extract_metadata(self):
+        try:
+            if self.print:
+                try:
+                    print(self.director_name, self.url)
+                except AttributeError:
+                    print(self.url)
+        except AttributeError:
+            pass
+        page_director = urlopen(self.url)
+        soup = BeautifulSoup(page_director, 'lxml')
+        try:
+            selected_section = soup.find_all('tbody', class_='celebrity-filmography__tbody')[0]
+        except IOError:
+            print('The parsing process returns an error.')
+
+        soup_filmography = BeautifulSoup(str(selected_section), 'lxml')
+        movie_metadata = defaultdict(dict)
+        for each_row in soup_filmography.find_all('tr'):
+            is_this_a_linked_movie = each_row.find('td', class_='celebrity-filmography__title').find('a')
+            if is_this_a_linked_movie is None:
+                next
+            else:
+                for each_cell in each_row.find_all('td', class_="celebrity-filmography__credits"):
+                    for each_string in each_cell.stripped_strings:
+                        if "Director" in each_string:
+                            try:
+                                this_title = each_row['data-title']
+                                movie_metadata[this_title]['Year'] = each_row['data-year']
+                                movie_metadata[this_title]['Score_Rotten'] = each_row['data-tomatometer']
+                                movie_metadata[this_title]['Box_Office'] = each_row['data-boxoffice']
+                            except IOError:
+                                pass
+        self.metadata = movie_metadata
