@@ -90,13 +90,14 @@ class TestRtParser(unittest.TestCase):
     def test_director_scraper_01(self):
         director_scraper = DirectorScraper(director_name='stanley kubrick')
         director_scraper.extract_metadata()
-        movie_titles = director_scraper.metadata.keys()
+        movie_titles = list(director_scraper.metadata.keys())
         self.assertIn('Eyes Wide Shut', movie_titles)
         
     def test_director_scraper_02(self):
-        director_scraper = DirectorScraper(director_url='https://www.rottentomatoes.com/celebrity/steven_spielberg')
+        director_url = 'https://www.rottentomatoes.com/celebrity/steven_spielberg'
+        director_scraper = DirectorScraper(director_url=director_url)
         director_scraper.extract_metadata()
-        movie_titles = director_scraper.metadata.keys()
+        movie_titles = list(director_scraper.metadata.keys())
         self.assertIn('Jaws', movie_titles)
         
     def test_director_scraper_03(self):
